@@ -2,7 +2,7 @@
 
 package Net::Prober;
 {
-  $Net::Prober::VERSION = '0.08';
+  $Net::Prober::VERSION = '0.10';
 }
 
 
@@ -106,13 +106,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Prober - Probes network hosts for downtime, latency, etc...
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -324,6 +326,19 @@ MD5 hash. B<You can calculate the MD5 of a given URL with>:
 
 What URL to download. By default it uses C</>.
 
+=item C<up_status_re>
+
+By default, any HTTP response with status 2xx or 3xx (redirect)
+will be considered successful. However, it is also possible to specify
+your own custom regular expression instead. In this way, you can consider
+"healthy" a host that replies to your HTTP probe with a 404 (not found)
+or other status code.
+
+Example:
+
+    up_status_re => '^[234]'
+    up_status_re => '^30[12]$'
+
 =back
 
 =head3 C<icmp> probe
@@ -346,7 +361,7 @@ Cosimo Streppone <cosimo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Cosimo Streppone.
+This software is copyright (c) 2014 by Cosimo Streppone.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
